==> plsql-maven-shared-1.4-sources.jar: com/google/code/plsqlmaven/shared/SchemaUtils.java <==
//
// Generated stub from file:/Users/andrea/Progetti/oss/googlecode/plsqlmaven/svn/trunk/target/checkout/plsql-maven-shared/src/main/groovy/com/google/code/plsqlmaven/shared/SchemaUtils.groovy
//

package com.google.code.plsqlmaven.shared;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import java.math.BigDecimal;
import java.math.BigInteger;
import groovy.sql.Sql;
import java.io.File;

/**
 * Basic mojo to extend for PL/SQL Goals
 */
public class SchemaUtils
    extends java.lang.Object
    implements groovy.lang.GroovyObject
{
    private java.lang.Object ant = null;

    private java.lang.Object log = null;

    private Sql sql = null;

    private java.lang.String username = null;

    /**
     * Type specific helpers
     */
    private java.lang.Object helpers = null;

    /**
     * Magic constructor
     */
    private SchemaUtils(java.lang.Void void0, java.lang.Void void1, java.lang.Void void2) {
        throw new InternalError("Stubbed method");
    }

    public SchemaUtils(java.lang.Object ant, java.lang.Object log, java.lang.Object sql) {
        this((java.lang.Void)null, (java.lang.Void)null, (java.lang.Void)null);
        throw new InternalError("Stubbed method");
    }

    public void syncDirectory(java.lang.Object dir) {
        throw new InternalError("Stubbed method");
    }

    public void sync(java.lang.Object objects) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getHelper(java.lang.Object type) {
        throw new InternalError("Stubbed method");
    }

    private java.lang.Object applyChanges(java.lang.Object helper, java.lang.Object changes, java.lang.Object detectOnly) {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}

==> plsql-maven-shared-1.11-sources.jar: com/google/code/plsqlmaven/shared/SchemaUtils.java <==
//
// Generated stub from file:/Users/andrea/Progetti/oss/googlecode/plsqlmaven/svn/trunk/target/checkout/plsql-maven-shared/src/main/groovy/com/google/code/plsqlmaven/shared/SchemaUtils.groovy
//

package com.google.code.plsqlmaven.shared;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import java.math.BigDecimal;
import java.math.BigInteger;
import groovy.sql.Sql;
import java.io.File;
import java.sql.SQLException;
import com.google.code.plsqlmaven.oraddl.helpers.DDLException;
import java.io.File;
import groovy.xml.MarkupBuilder;

/**
 * Basic mojo to extend for PL/SQL Goals
 */
public class SchemaUtils
    extends java.lang.Object
    implements groovy.lang.GroovyObject
{
    private java.lang.Object ant = null;

    private java.lang.Object log = null;

    private Sql sql = null;

    private java.lang.String username = null;

    /**
     * Type specific helpers
     */
    private java.lang.Object helpers = null;

    /**
     * Magic constructor
     */
    private SchemaUtils(java.lang.Void void0, java.lang.Void void1, java.lang.Void void2) {
        throw new InternalError("Stubbed method");
    }

    public SchemaUtils(java.lang.Object ant, java.lang.Object log, java.lang.Object sql) {
        this((java.lang.Void)null, (java.lang.Void)null, (java.lang.Void)null);
        throw new InternalError("Stubbed method");
    }

    public SchemaUtils(java.lang.Object ant, java.lang.Object log) {
        this((java.lang.Void)null, (java.lang.Void)null, (java.lang.Void)null);
        throw new InternalError("Stubbed method");
    }

    public void setSql(java.lang.Object sql) {
        throw new InternalError("Stubbed method");
    }

    public void syncDirectory(java.lang.Object dir) {
        throw new InternalError("Stubbed method");
    }

    public boolean sync(java.lang.Object objects) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object extractXml(java.lang.Object parser, java.lang.Object helper, java.lang.Object name) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object extractFile(java.lang.Object targetDir, java.lang.Object type, java.lang.Object name) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getHelper(java.lang.Object type) {
        throw new InternalError("Stubbed method");
    }

    private java.lang.Object applyChanges(java.lang.Object helper, java.lang.Object changes, java.lang.Object detectOnly) {
        throw new InternalError("Stubbed method");
    }

    public static java.lang.Object getSourceDescriptor(File source) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getSchemaSourceFiles(java.lang.Object dir) {
        throw new InternalError("Stubbed method");
    }

    private java.lang.Object ensureList(java.lang.Object o) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.String path(java.lang.Object p) {
        throw new InternalError("Stubbed method");
    }

    private java.lang.Object initcap(java.lang.Object str) {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}
